@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Template::Overlay;
-$Template::Overlay::VERSION = '1.10';
+$Template::Overlay::VERSION = '1.11';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
@@ -39,11 +39,11 @@ sub _overlay_files {
     my %overlay_files = ();
     foreach my $overlay ( ref($overlays) eq 'ARRAY' ? @$overlays : ($overlays) ) {
         $overlay = File::Spec->rel2abs($overlay);
-        my $length = length($overlay);
+        my $base_path_length = length($overlay);
         find(
             sub {
                 if ( -f $File::Find::name && $_ !~ /~$/ && $_ !~ /^\..+\.swp$/ ) {
-                    my $relative = substr( $File::Find::name, $length );
+                    my $relative = _relative_path( $File::Find::name, $base_path_length );
                     $overlay_files{$relative} = $File::Find::name;
                 }
             },
@@ -61,10 +61,10 @@ sub overlay {
     my $destination   = $self->{base};
     if ( $options{to} && $options{to} ne $self->{base} ) {
         $destination = File::Spec->rel2abs( $options{to} );
-        my $length = length( File::Spec->rel2abs( $self->{base} ) );
+        my $base_path_length = length( File::Spec->rel2abs( $self->{base} ) );
         find(
             sub {
-                my $relative = substr( $File::Find::name, $length );
+                my $relative = _relative_path( $File::Find::name, $base_path_length );
                 if ( -d $File::Find::name ) {
                     make_path( File::Spec->catdir( $destination, $relative ) );
                 }
@@ -89,6 +89,14 @@ sub overlay {
     }
 }
 
+sub _relative_path {
+    my ( $path, $base_path_length ) = @_;
+    return
+        length($path) == $base_path_length
+        ? ''
+        : substr( $File::Find::name, $base_path_length + 1 );
+}
+
 sub _resolve {
     my ( $self, $template, $file, $resolver ) = @_;
 
@@ -128,7 +136,7 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
